==> apache-shenyu-2.6.1-src.zip: apache-shenyu-2.6.1-src/shenyu-plugin/shenyu-plugin-security/shenyu-plugin-basic-auth/src/test/java/org/apache/shenyu/plugin/basic/auth/rule/BasicAuthRuleHandleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.basic.auth.rule;

import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.isA;
import static org.hamcrest.Matchers.nullValue;
import static org.junit.Assert.assertThat;

/**
 * Test case for {@link BasicAuthRuleHandle}.
 */
public class BasicAuthRuleHandleTest {

    @Test
    public void testGetInstance() {
        assertThat(BasicAuthRuleHandle.newInstance(null), nullValue());

        assertThat(BasicAuthRuleHandle.newInstance("{\"handleType\":\"custom\"}"),
                isA(CustomBasicAuthRuleHandle.class));

        assertThat(BasicAuthRuleHandle.newInstance("{\"authorization\":\"test:test123\"}"),
                isA(DefaultBasicAuthRuleHandle.class));
    }

}

==> apache-shenyu-2.7.0.3-src.zip: apache-shenyu-2.7.0.3-src/shenyu-plugin/shenyu-plugin-security/shenyu-plugin-basic-auth/src/test/java/org/apache/shenyu/plugin/basic/auth/rule/BasicAuthRuleHandleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.plugin.basic.auth.rule;

import org.junit.jupiter.api.Test;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.isA;
import static org.hamcrest.Matchers.nullValue;

/**
 * Test case for {@link BasicAuthRuleHandle}.
 */
public class BasicAuthRuleHandleTest {

    @Test
    public void testGetInstance() {
        assertThat(BasicAuthRuleHandle.newInstance(null), nullValue());

        assertThat(BasicAuthRuleHandle.newInstance("{\"handleType\":\"custom\"}"),
                isA(CustomBasicAuthRuleHandle.class));

        assertThat(BasicAuthRuleHandle.newInstance("{\"authorization\":\"test:test123\"}"),
                isA(DefaultBasicAuthRuleHandle.class));
    }

}
